@@ -1,4 +1,4 @@
-//$Id: radiobuttons.cc,v 1.4 2002/07/09 12:21:00 murrayc Exp $ -*- c++ -*-
+//$Id: radiobuttons.cc 386 2005-04-06 12:20:09Z  $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -31,7 +31,7 @@ RadioButtons::RadioButtons() :
   set_border_width(0);
 
   //Put radio buttons 2 and 3 in the same group as 1:
-  Gtk::RadioButton::Group group =m_RadioButton1.get_group();
+  Gtk::RadioButton::Group group = m_RadioButton1.get_group();
   m_RadioButton2.set_group(group);
   m_RadioButton3.set_group(group);
 
@@ -48,18 +48,18 @@ RadioButtons::RadioButtons() :
   m_RadioButton2.set_active();
 
   //Add a separator:
-  m_Box_Top.pack_start(m_Separator, Gtk::FILL);
+  m_Box_Top.pack_start(m_Separator, Gtk::PACK_SHRINK);
 
   //Put Box2 in m_Box_Top:
   m_Box2.set_border_width(10);
-  m_Box_Top.pack_start(m_Box2, Gtk::FILL);
+  m_Box_Top.pack_start(m_Box2, Gtk::PACK_SHRINK);
 
   //Put Close button in Box2:
   m_Box2.pack_start(m_Button_Close);
   m_Button_Close.set_flags(Gtk::CAN_DEFAULT);
   m_Button_Close.grab_default();
 
-  m_Button_Close.signal_clicked().connect( SigC::slot(*this, &RadioButtons::on_button_clicked) );
+  m_Button_Close.signal_clicked().connect( sigc::mem_fun(*this, &RadioButtons::on_button_clicked) );
 
   show_all_children();
 }
