@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.4 2004/03/10 01:17:33 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc 386 2005-04-06 12:20:09Z  $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -177,7 +177,7 @@ void ExampleWindow::update_paste_status()
 void ExampleWindow::on_clipboard_received_targets(const Glib::StringArrayHandle& targets_array)
 {
   // Get the list of available clipboard targets:
-  std::list<std::string> targets (targets_array);
+  std::list<std::string> targets = targets_array;
 
   const bool bPasteIsPossible =
       std::find(targets.begin(), targets.end(), example_target_custom) != targets.end();
