@@ -1,4 +1,4 @@
-//$Id: client.h,v 1.1.1.1 2003/01/21 13:41:35 murrayc Exp $ -*- c++ -*-
+//$Id: client.h 386 2005-04-06 12:20:09Z  $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -21,9 +21,9 @@
 
 #include <sigc++/sigc++.h>
 
-//Client must inherit from SigC::Object.
+//Client must inherit from sigc::trackable.
 //because libsigc++ needs to keep track of the lifetime of signal handlers.
-class Client : public SigC::Object
+class Client : public sigc::trackable
 {
 public:
   Client();
