@@ -1,4 +1,4 @@
-/* $Id: gtkmm.h,v 1.10 2004/09/11 09:16:10 murrayc Exp $ */
+/* $Id: gtkmm.h 278 2004-11-04 21:42:25Z murrayc $ */
 /* gtkmm - a C++ wrapper for the Gtk toolkit
  *
  * Copyright 1999-2002 The gtkmm Development Team
@@ -45,7 +45,9 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/checkmenuitem.h>
 #include <gtkmm/cellrenderer.h>
+#include <gtkmm/cellrenderercombo.h>
 #include <gtkmm/cellrendererpixbuf.h>
+#include <gtkmm/cellrendererprogress.h>
 #include <gtkmm/cellrenderertext.h>
 #include <gtkmm/cellrenderertoggle.h>
 #include <gtkmm/colorbutton.h>
@@ -67,6 +69,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/filechooser.h>
 #include <gtkmm/filechooserbutton.h>
 #include <gtkmm/filechooserdialog.h>
+#include <gtkmm/filechooserwidget.h>
 #include <gtkmm/filefilter.h>
 #include <gtkmm/fileselection.h> //TODO: Deprecated.
 #include <gtkmm/fixed.h>
