@@ -1,4 +1,4 @@
-/* $Id: treeview_private.cc,v 1.2.2.1 2006/04/20 12:12:09 murrayc Exp $ */
+/* $Id: treeview_private.cc 614 2006-05-11 08:14:05Z murrayc $ */
 
 /* Copyright(C) 2001-2002 The gtkmm Development Team
  *
@@ -32,15 +32,19 @@ void SignalProxy_CellData_gtk_callback(GtkTreeViewColumn*, GtkCellRenderer* cell
 {
   TreeViewColumn::SlotCellData* the_slot = static_cast<TreeViewColumn::SlotCellData*>(data);
 
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
+  #endif //GLIBMM_EXCEPTIONS_ENABLE
     // use Slot::operator()
     (*the_slot)(Glib::wrap(cell, false), TreeIter(model, iter));
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(...)
   {
     Glib::exception_handlers_invoke();
   }
+  #endif //GLIBMM_EXCEPTIONS_ENABLE
 }
 
 void SignalProxy_CellData_gtk_callback_destroy(void* data)
@@ -53,9 +57,12 @@ gboolean SignalProxy_RowSeparator_gtk_callback(GtkTreeModel* model, GtkTreeIter*
 {
   TreeView::SlotRowSeparator* the_slot = static_cast<TreeView::SlotRowSeparator*>(data);
 
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
+  #endif //GLIBMM_EXCEPTIONS_ENABLE
     return (*the_slot)(Glib::wrap(model, true), Gtk::TreeIter(model, iter));
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(...)
   {
@@ -63,6 +70,7 @@ gboolean SignalProxy_RowSeparator_gtk_callback(GtkTreeModel* model, GtkTreeIter*
   }
 
   return 0; // arbitrary value
+  #endif //GLIBMM_EXCEPTIONS_ENABLE
 }
 
 void SignalProxy_RowSeparator_gtk_callback_destroy(void* data)
